package hudson.plugins.artifactsize;

import hudson.model.AbstractBuild;
import hudson.model.Action;

import org.kohsuke.stapler.export.Exported;
import org.kohsuke.stapler.export.ExportedBean;

/**
 * This action stores the total size (in bytes) of all artifacts archived by
 * Hudson for a specific build.
 * 
 * @author swiest
 */
@ExportedBean
public class ArtifactSizeAction implements Action {

  private final long totalSize;

  private final AbstractBuild build;

  public ArtifactSizeAction(long totalSize, AbstractBuild build) {
    this.totalSize = totalSize;
    this.build = build;

  }

  @Exported(visibility = 2)
  public long getTotalSize() {
    return totalSize;
  }

  public AbstractBuild getBuild() {
    return build;
  }

  public String getDisplayName() {
    return Messages.ArtifactSizeAction_ShowArtifactSize();
  }

  public String getIconFileName() {
    return "monitor.gif";
  }

  public String getUrlName() {
    return "artifactsize";
  }

}