package hudson.plugins.artifactsize;

import hudson.Extension;
import hudson.Launcher;
import hudson.model.AbstractBuild;
import hudson.model.AbstractProject;
import hudson.model.BuildListener;
import hudson.model.Run.Artifact;
import hudson.tasks.BuildStepDescriptor;
import hudson.tasks.BuildStepMonitor;
import hudson.tasks.Publisher;
import hudson.tasks.Recorder;

import java.io.IOException;
import java.util.List;

import org.kohsuke.stapler.DataBoundConstructor;

/**
 * This recorder is called upon completion of a build and sums up the sizes of
 * all artifacts archived by Hudson for this specific build. The total sum is
 * stored in a ArtifactSizeAction along with the build.
 * 
 * @author swiest
 */
public class ArtifactSizeRecorder extends Recorder {

  @DataBoundConstructor
  public ArtifactSizeRecorder() {
    // Required by Stapler framework.
  }

  public boolean perform(AbstractBuild build, Launcher launcher, BuildListener listener) throws InterruptedException, IOException {
    long totalSize = 0;
    List<Artifact> artifacts = build.getArtifacts();
    for (Artifact artifact : artifacts) {
      totalSize += artifact.getFile().length();
    }
    build.addAction(new ArtifactSizeAction(totalSize, build));
    listener.getLogger().println("Total artifacts size: " + totalSize + " byte(s).");
    return true;
  }

  public BuildStepMonitor getRequiredMonitorService() {
    return BuildStepMonitor.NONE;
  }

  @Extension
  public static class ArtifactSizeRecorderDescriptor extends BuildStepDescriptor<Publisher> {

    @Override
    public String getDisplayName() {
      return "Record Artifact Sizes";
    }

    @Override
    public boolean isApplicable(Class<? extends AbstractProject> jobType) {
      return true;
    }

  }
}